@@ -1,12 +1,13 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package Cave::Wrapper;
-$Cave::Wrapper::VERSION = '0.01100100';
+
 # ABSTRACT: A Wrapper to the Paludis 'cave' Client.
 
+our $VERSION = '1.000000';
+
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 
@@ -153,7 +154,7 @@ Cave::Wrapper - A Wrapper to the Paludis 'cave' Client.
 
 =head1 VERSION
 
-version 0.01100100
+version 1.000000
 
 =head1 DESCRIPTION
 
@@ -241,7 +242,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2015 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
